
class Keys:
    PIPELINE = 'pipeline'
    DATASET_DEFINITION = 'dataset_definition'
    DEFAULTS = 'variable_defaults'
    QUALITY_MANAGEMENT = 'quality_management'
    ATTRIBUTES = 'attributes'
    DIMENSIONS = 'dimensions'
    VARIABLES = 'variables'
    ALL = 'ALL'
